/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "DataSetWidget.h"

#include "CustomToolBar.h"
#include "IconEngine.h"
#include "IconNames.h"
#include "IconSize.h"

#include <QStringList>
#include <QLayout>
#include <QLabel>

//______________________________________________________________________________
DataSetWidget::DataSetWidget( QWidget* parent ):
    QWidget( parent ),
    Counter( "DataSetWidget" )
{

    Debug::Throw( "DataSetWidget::DataSetWidget" );
    QHBoxLayout* layout( new QHBoxLayout );
    layout->setMargin(0);
    setLayout( layout );

    QLabel* label;
    layout->addWidget( label = new QLabel( tr( "Marker set:" ), this ) );
    layout->addWidget( combobox_ = new QComboBox( this ) );
    label->setBuddy( combobox_ );

    combobox_->setSizeAdjustPolicy( QComboBox::AdjustToContents );
    combobox_->setDuplicatesEnabled( false );
    connect( combobox_, SIGNAL(currentIndexChanged(int)), SLOT(_indexChanged(int)) );

    // actions
    addAction( addAction_ = new QAction( IconEngine::get( IconNames::Add ), tr( "Add Data Set" ), this ) );
    connect( addAction_, SIGNAL(triggered()), SIGNAL(dataSetAdded()) );

    addAction( removeAction_ = new QAction( IconEngine::get( IconNames::Remove ), tr( "Remove Data Set" ), this ) );
    connect( removeAction_, SIGNAL(triggered()), SIGNAL(dataSetRemoved()) );

    // toolbar
    CustomToolBar* toolbar( new CustomToolBar( tr( "Data Sets" ), this ) );
    toolbar->setTransparent( true );
    toolbar->setMovable( false );
    toolbar->setToolButtonStyle(Qt::ToolButtonIconOnly );
    toolbar->setIconSize( IconSize::get( IconSize::Small ) );
    toolbar->addAction( addAction_ );
    toolbar->addAction( removeAction_ );

    // layout
    layout->addWidget( toolbar );
    layout->addStretch( 1 );
}

//______________________________________________________________________________
void DataSetWidget::setCollection( const RefPoint::Collection& collection )
{

    Debug::Throw( "DataSetWidget::setCollection" );

    locked_ = true;

    QStringList items;
    for( int index = 0; index < (int) collection.size(); index++ )
    {
        const QString buffer = QString( tr( "Set %1" ) ).arg( index+1 );
        items << buffer;
    }

    combobox_->clear();
    combobox_->addItems( items );

    removeAction_->setEnabled( collection.size() > 1 );
    locked_ = false;

}
