#ifndef DefaultOptions_h
#define DefaultOptions_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Color.h"
#include "File.h"
#include "PrintListDialog.h"
#include "RefPoint.h"
#include "RefPointModel.h"
#include "Util.h"
#include "XmlOptions.h"

//_____________________________________________________
//* Default options installer
void installDefaultOptions()
{
    // set options default values
    XmlOptions::get().setAutoDefault( true );

    // icon
    XmlOptions::get().set<int>( "MAIN_WINDOW_HEIGHT", 750 );
    XmlOptions::get().set<int>( "MAIN_WINDOW_WIDTH", 700 );

    XmlOptions::get().set<int>( "REFPOINT_LIST_MASK", (1<<RefPointModel::Local)|(1<<RefPointModel::Index) );
    XmlOptions::get().set<int>( "REFPOINT_LIST_SORT_COLUMN", RefPointModel::Local );
    XmlOptions::get().set<bool>( "REFPOINT_TOOLBAR", true );

    XmlOptions::get().set( "SCROLL_AREA_COLOR", Base::Color( "#666666" ) );

    XmlOptions::get().set<int>( "POINT_SIZE", 10 );
    XmlOptions::get().set<int>( "PEN_SIZE", 2 );
    XmlOptions::get().set( "INACTIVE_POINT_COLOR", Base::Color( "#cccccc" ) );
    XmlOptions::get().set( "POINT_COLOR", Base::Color( "#ff8c00" ) );
    XmlOptions::get().set( "REF_POINT_COLOR", Base::Color( "#0000aa" ) );
    XmlOptions::get().set( "SELECTED_POINT_COLOR", Base::Color( "#aa0000" ) );
    XmlOptions::get().set( "HOVER_POINT_COLOR", Base::Color( "#ffd100" ) );

    XmlOptions::get().set<bool>( "SHOW_INACTIVE_POINTS", 1 );
    XmlOptions::get().set<bool>( "SHOW_REF_POINTS", 1 );
    XmlOptions::get().set<bool>( "SHOW_SCAN_LINES", 1 );

    // zoom
    XmlOptions::get().set<double>( "ZOOM_FACTOR", 1.0 );
    XmlOptions::get().set<int>( "ZOOM_MODE", 3 );

    // errors
    XmlOptions::get().set<RefPoint::ErrorMode>( "DEFAULT_ERROR_X_MODE", RefPoint::NoError );
    XmlOptions::get().set<double>( "DEFAULT_ERROR_X_PLUS", 0 );
    XmlOptions::get().set<double>( "DEFAULT_ERROR_X_MINUS", 0 );
    XmlOptions::get().set<bool>( "DEFAULT_ERROR_X_RELATIVE", true );

    XmlOptions::get().set<RefPoint::ErrorMode>( "DEFAULT_ERROR_Y_MODE", RefPoint::ErrorSymetric );
    XmlOptions::get().set<double>( "DEFAULT_ERROR_Y_PLUS", 0.2 );
    XmlOptions::get().set<double>( "DEFAULT_ERROR_Y_MINUS", 0.2 );
    XmlOptions::get().set<bool>( "DEFAULT_ERROR_Y_RELATIVE", true );

    XmlOptions::get().set<RefPoint::ErrorMode>( "DEFAULT_ERROR_SYST_X_MODE", RefPoint::NoError );
    XmlOptions::get().set<double>( "DEFAULT_ERROR_SYST_X_PLUS", 0 );
    XmlOptions::get().set<double>( "DEFAULT_ERROR_SYST_X_MINUS", 0 );
    XmlOptions::get().set<bool>( "DEFAULT_ERROR_SYST_X_RELATIVE", true );

    XmlOptions::get().set<RefPoint::ErrorMode>( "DEFAULT_ERROR_SYST_Y_MODE", RefPoint::ErrorSymetric );
    XmlOptions::get().set<double>( "DEFAULT_ERROR_SYST_Y_PLUS", 0.25 );
    XmlOptions::get().set<double>( "DEFAULT_ERROR_SYST_Y_MINUS", 0.25 );
    XmlOptions::get().set<bool>( "DEFAULT_ERROR_SYST_Y_RELATIVE", true );

    // notifications
    XmlOptions::get().set<bool>( "SHOW_NOTIFICATIONS", true );
    XmlOptions::get().set<bool>( "AUTO_HIDE_NOTIFICATIONS", true );
    XmlOptions::get().set<bool>( "ANIMATE_NOTIFICATIONS", true );
    XmlOptions::get().set<int>( "AUTO_HIDE_DELAY", 3000 );
    XmlOptions::get().set<int>( "ANIMATION_DURATION", 200 );

    // format
    XmlOptions::get().set( "GLOBAL_FORMAT", "%.3f" );
    XmlOptions::get().set( "LOCAL_FORMAT", "%.3f" );
    XmlOptions::get().set( "ERROR_FORMAT", "%.3f" );

    // default print format
    XmlOptions::get().set<int>( "PRINT_FORMAT", PrintListDialog::FormatC );
    XmlOptions::get().set<int>( "DB_SIZE", 0 );

    // resource file
    XmlOptions::get().set( "OLD_RC_FILE", Option( File(".graphscanrc").addPath(Util::home()), Option::Flag::None ) );
    XmlOptions::get().set( "RC_FILE", Option( File("graphscanrc").addPath(Util::config()), Option::Flag::None ) );

    XmlOptions::get().setAutoDefault( false );

};

#endif
