#ifndef ImageRecordModel_h
#define ImageRecordModel_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"
#include "Debug.h"
#include "ImageRecord.h"
#include "ListModel.h"

#include <QStringList>

//* qlistview for object counters
class ImageRecordModel: public ListModel<ImageRecord>, private Base::Counter<ImageRecordModel>
{

    Q_OBJECT

    public:

    //* column type enumeration
    enum ColumnType
    {
        Filename,
        Path,
        Time
    };

    //* constructor
    explicit ImageRecordModel( QObject* = nullptr );

    //*@name methods reimplemented from base class
    //@{

    //* flags
    Qt::ItemFlags flags( const QModelIndex& ) const override;

    // return data for a given index
    QVariant data( const QModelIndex&, int ) const override;

    //* header data
    QVariant headerData( int, Qt::Orientation, int = Qt::DisplayRole ) const override;

    //* number of columns for a given index
    int columnCount( const QModelIndex& = QModelIndex() ) const override;

    //* column matching given name, if any
    int findColumn( const QString& ) const;

    //@}

    protected:

    //* sort
    void _sort( int column, Qt::SortOrder order ) override;

    private:

    //* used to sort Counters
    class SortFTor: public ItemModel::SortFTor
    {

        public:

        //* constructor
        explicit SortFTor( int type, Qt::SortOrder order, const QStringList& column_titles ):
            ItemModel::SortFTor( type, order ),
            columnTitles_( column_titles )
        {}

        //* prediction
        bool operator() ( ImageRecord, ImageRecord ) const;

        private:

        // column titles
        QStringList columnTitles_;

    };

    //* update columns
    void _updateColumns( const ValueType& );;

    //* column titles
    QStringList columnTitles_;

};

#endif
