#ifndef NotificationWidget_h
#define NotificationWidget_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include <QLabel>

#include "Counter.h"

#include <QPaintEvent>
#include <QPropertyAnimation>
#include <QBasicTimer>
#include <QTimerEvent>

class NotificationWidget: public QLabel, private Base::Counter<NotificationWidget>
{

    Q_OBJECT
    Q_PROPERTY( qreal opacity READ opacity WRITE setOpacity )

    public:

    //* constructor
    explicit NotificationWidget( QWidget* );

    //* set text
    void setText( const QString& );

    //* clear
    void clear()
    { hide(); }

    //* visibility
    void setVisible( bool ) override;

    //* opacity
    int opacity() const
    { return opacity_; }

    //* opacity
    void setOpacity( int );

    protected:

    //* paint event
    void paintEvent( QPaintEvent* );

    //* timer event
    void timerEvent( QTimerEvent* ) override;

    private Q_SLOTS:

    void _updateConfiguration();

    private:

    //* enable state
    bool enabled_ = true;

    //* auto hide
    bool autoHide_ = true;

    //* auto hide delay
    int autoHideDelay_ = 3000;

    //* autohide timer
    QBasicTimer timer_;

    //* true if animated
    bool isAnimated_ = true;

    //* fade in/fade out animation
    QPropertyAnimation animation_;

    //* opacity
    int opacity_ = 0;

};

#endif
