#ifndef PrintListDialog_h
#define PrintListDialog_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "CustomDialog.h"
#include "RefPoint.h"

#include <QCheckBox>
#include <QComboBox>
#include <QGroupBox>
#include <QLayout>
#include <QToolButton>

#include <QList>
#include <QStringList>

class TextEditor;

class PrintListDialog: public CustomDialog
{

    Q_OBJECT

    public:

    //* format
    enum Format
    {
        FormatRaw,
        FormatLatex,
        FormatC
    };

    //* constructor
    explicit PrintListDialog( QWidget* );

    //* set ref points
    void setCollection( const RefPoint::Collection&, int = -1 );

    //* format tool button
    QToolButton& formatToolButton() const
    { return *formatToolButton_; }

    public Q_SLOTS:

    //* selection changed
    void updateText();

    protected Q_SLOTS:

    //* save format
    void _saveFormat();

    protected:

    //* print data set
    QString _printDataSet( int ) const;

    //* print data set
    QString _printDataSet( const RefPoint::List&, const QString& = QString() ) const;

    //* print data set
    QString _printDataSetRaw( const RefPoint::List&, const QString& = QString() ) const;

    //* print data set
    QString _printDataSetLatex( const RefPoint::List&, const QString& = QString() ) const;

    //* print data set
    QString _printDataSetC( const RefPoint::List&, const QString& = QString() ) const;

    //* print array
    QString _printArray( const QString&, const QStringList& ) const;

    //* var name
    QString _varName( const QString& var, const QString& name ) const
    { return name.isEmpty() ? var : var + "_" + name; }

    enum Column
    {
        ColumnsNone = 0,
        ColumnsX = 1<<0,
        ColumnsXStat = 1<<1,
        ColumnsXSyst = 1<<2,
        ColumnsY = 1<<3,
        ColumnsYStat = 1<<4,
        ColumnsYSyst = 1<<5,
        ColumnsXAll = ColumnsX | ColumnsXStat | ColumnsXSyst,
        ColumnsYAll = ColumnsY | ColumnsYStat | ColumnsYSyst,
        ColumnsAll = ColumnsXAll | ColumnsYAll
    };

    Q_DECLARE_FLAGS( Columns, Column )

    //* columns
    Columns _columns( const RefPoint::List& ) const;

    //* max length in array
    int _maxLength( const QStringList& ) const;

    //* normalize
    void _normalize( QStringList& ) const;

    private:

    class RefPointString final: private Base::Counter<RefPointString>
    {

        public:

        //* constructor
        explicit RefPointString():
            Counter( "PrintListDialog::RefPointString" )
        {}

        //* set ref point
        RefPointString& set( const RefPoint&, const QString& localFormat = QString(), const QString& errorFormat = QString() );

        //*@name accessors
        //@{
        const QString& x() const { return x_; }
        const QString& xStatPlus() const { return xStatPlus_; }
        const QString& xStatMinus() const { return xStatMinus_; }
        const QString& xSystPlus() const { return xSystPlus_; }
        const QString& xSystMinus() const { return xSystMinus_; }

        const QString& y() const { return y_; }
        const QString& yStatPlus() const { return yStatPlus_; }
        const QString& yStatMinus() const { return yStatMinus_; }
        const QString& ySystPlus() const { return ySystPlus_; }
        const QString& ySystMinus() const { return ySystMinus_; }
        //@}

        protected:

        //* formated string
        QString _string( const double& value, const QString& format ) const;

        private:

        QString x_;
        QString xStatPlus_;
        QString xStatMinus_;
        QString xSystPlus_;
        QString xSystMinus_;

        QString y_;
        QString yStatPlus_;
        QString yStatMinus_;
        QString ySystPlus_;
        QString ySystMinus_;

    };

    using RefPointStringList = QList<RefPointString>;

    static RefPointStringList refPointStringList( const RefPoint::List&, const QString& localFormat = QString(), const QString& errorFormat = QString() );

    //* main grid layout
    QGridLayout* gridLayout_ = nullptr;

    //* format container
    QWidget* formatContainer_ = nullptr;

    //* format combobox
    QComboBox* formatComboBox_ = nullptr;

    //* format tool button
    QToolButton* formatToolButton_ = nullptr;

    //* checkbox container
    QWidget* checkBoxContainer_ = nullptr;

    //* vertical layout of for checkboxes
    QVBoxLayout* checkBoxLayout_ = nullptr;

    //* list of checkboxes for dataset selection
    using CheckBoxList = QList<QCheckBox*>;
    CheckBoxList checkBoxes_;

    //* editor
    TextEditor* editor_ = nullptr;

    //* collection
    RefPoint::Collection collection_;

    //* format
    Format format_ = FormatRaw;

};

#endif
