/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "RefPointDefaultErrorDialog.h"

#include "CustomComboBox.h"
#include "GridLayout.h"
#include "XmlOptions.h"

#include <QLabel>
#include <QDoubleValidator>

//_____________________________________________________________________
RefPointDefaultErrorDialog::RefPointDefaultErrorDialog( QWidget* parent ):
    CustomDialog( parent, OkButton|CancelButton|Separator )
{

    setWindowTitle( "Edit Marker Default Uncertainties - Graphscan" );
    setOptionName( "REFPOINT_DEFAULT_ERROR_DIALOG" );

    GridLayout* gridLayout = new GridLayout;
    gridLayout->setMaxCount( 5 );
    gridLayout->setMargin(5);
    gridLayout->setSpacing(5);
    mainLayout().addLayout( gridLayout );

    QLabel* label = nullptr;
    gridLayout->addWidget( label = new QLabel( tr( "Horizontal statistical uncertainty:" ), this ) );
    label->setAlignment( Qt::AlignRight|Qt::AlignVCenter );
    xErrorWidget_ = new RefPointErrorWidget( this );
    gridLayout->addWidget( &xErrorWidget_->comboBox() );
    gridLayout->addWidget( &xErrorWidget_->plusEditor() );
    gridLayout->addWidget( &xErrorWidget_->minusEditor() );
    gridLayout->addWidget( &xErrorWidget_->relativeCheckBox() );

    gridLayout->addWidget( label = new QLabel( tr( "Vertical statistical uncertainty:" ), this ) );
    label->setAlignment( Qt::AlignRight|Qt::AlignVCenter );
    yErrorWidget_ = new RefPointErrorWidget( this );
    gridLayout->addWidget( &yErrorWidget_->comboBox() );
    gridLayout->addWidget( &yErrorWidget_->plusEditor() );
    gridLayout->addWidget( &yErrorWidget_->minusEditor() );
    gridLayout->addWidget( &yErrorWidget_->relativeCheckBox() );

    // horizontal systematic errors are not supported
    xErrorSystWidget_ = new RefPointErrorWidget( this );
    xErrorSystWidget_->hide();

    gridLayout->addWidget( label = new QLabel( tr( "Vertical systematic uncertainty:" ), this ) );
    label->setAlignment( Qt::AlignRight|Qt::AlignVCenter );
    yErrorSystWidget_ = new RefPointErrorWidget( this );
    gridLayout->addWidget( &yErrorSystWidget_->comboBox() );
    gridLayout->addWidget( &yErrorSystWidget_->plusEditor() );
    gridLayout->addWidget( &yErrorSystWidget_->minusEditor() );
    gridLayout->addWidget( &yErrorSystWidget_->relativeCheckBox() );

    sessionCheckBox_ = new QCheckBox( tr( "Apply changes to this session only" ), this );
    sessionCheckBox_->setChecked( true );

//     gridLayout->increment();
//     gridLayout->addWidget( sessionCheckBox_,
//         gridLayout->currentRow(), gridLayout->currentColumn(),
//         1, 5 );
//

    buttonLayout().insertWidget( 0, sessionCheckBox_ );
}
