#ifndef RefPointDefaultErrorDialog_h
#define RefPointDefaultErrorDialog_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "CustomDialog.h"
#include "RefPoint.h"
#include "RefPointErrorWidget.h"

#include <QCheckBox>

class RefPointDefaultErrorDialog: public CustomDialog
{

    Q_OBJECT

    public:

    //* constructor
    explicit RefPointDefaultErrorDialog( QWidget* );

    //*@name accessors
    //@{
    RefPoint::Error errorX() const
    { return xErrorWidget_->error(); }

    RefPoint::Error errorY() const
    { return yErrorWidget_->error(); }

    RefPoint::Error errorSystX() const
    { return xErrorSystWidget_->error(); }

    RefPoint::Error errorSystY() const
    { return yErrorSystWidget_->error(); }

    bool thisSessionOnly() const
    { return sessionCheckBox_->isChecked(); }

    //@}

    //*@name modifiers
    //@{
    void setErrorX( const RefPoint::Error& error )
    { xErrorWidget_->setError( error ); }

    void setErrorY( const RefPoint::Error& error )
    { yErrorWidget_->setError( error ); }

    void setErrorSystX( const RefPoint::Error& error )
    { xErrorSystWidget_->setError( error ); }

    void setErrorSystY( const RefPoint::Error& error )
    { yErrorSystWidget_->setError( error ); }

    //@}

    private:

    //* error widget
    RefPointErrorWidget* xErrorWidget_ = nullptr;

    //* error widget
    RefPointErrorWidget* yErrorWidget_ = nullptr;

    //* error widget
    RefPointErrorWidget* xErrorSystWidget_ = nullptr;

    //* error widget
    RefPointErrorWidget* yErrorSystWidget_ = nullptr;

    //* session
    QCheckBox* sessionCheckBox_ = nullptr;

};

#endif
