/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "RefPointErrorDialog.h"

#include "CustomComboBox.h"
#include "GridLayout.h"
#include "XmlOptions.h"

#include <QLabel>
#include <QDoubleValidator>

//_____________________________________________________________________
RefPointErrorDialog::RefPointErrorDialog( QWidget* parent ):
    CustomDialog( parent, OkButton|CancelButton|Separator )
{

    setWindowTitle( "Edit Marker Uncertainties - Graphscan" );
    setOptionName( "REFPOINT_ERROR_DIALOG" );

    GridLayout* gridLayout( new GridLayout );
    gridLayout->setMaxCount( 2 );
    gridLayout->setMargin(0);
    gridLayout->setSpacing(5);
    mainLayout().addLayout( gridLayout );

    QLabel* label;
    gridLayout->addWidget( label = new QLabel( tr( "Global coordinates:" ), this ) );
    gridLayout->addWidget( globalLabel_ = new QLabel( this ) );
    label->setAlignment( Qt::AlignRight|Qt::AlignVCenter );

    gridLayout->addWidget( label = new QLabel( tr( "Local coordinates:" ), this ) );
    gridLayout->addWidget( localLabel_ = new QLabel( this ) );
    label->setAlignment( Qt::AlignRight|Qt::AlignVCenter );

    QFrame* frame( new QFrame( this ) );
    frame->setFrameStyle( QFrame::HLine );
    mainLayout().addWidget( frame );

    gridLayout = new GridLayout;
    gridLayout->setMaxCount( 5 );
    gridLayout->setMargin(5);
    gridLayout->setSpacing(5);
    mainLayout().addLayout( gridLayout );

    gridLayout->addWidget( label = new QLabel( tr( "Horizontal statistical uncertainty:" ), this ) );
    label->setAlignment( Qt::AlignRight|Qt::AlignVCenter );
    xErrorWidget_ = new RefPointErrorWidget( this );
    gridLayout->addWidget( &xErrorWidget_->comboBox() );
    gridLayout->addWidget( &xErrorWidget_->plusEditor() );
    gridLayout->addWidget( &xErrorWidget_->minusEditor() );
    gridLayout->addWidget( &xErrorWidget_->relativeCheckBox() );

    gridLayout->addWidget( label = new QLabel( tr( "Vertical statistical uncertainty:" ), this ) );
    label->setAlignment( Qt::AlignRight|Qt::AlignVCenter );
    yErrorWidget_ = new RefPointErrorWidget( this );
    gridLayout->addWidget( &yErrorWidget_->comboBox() );
    gridLayout->addWidget( &yErrorWidget_->plusEditor() );
    gridLayout->addWidget( &yErrorWidget_->minusEditor() );
    gridLayout->addWidget( &yErrorWidget_->relativeCheckBox() );

    // horizontal systematic errors are not supported
    xErrorSystWidget_ = new RefPointErrorWidget( this );
    xErrorSystWidget_->hide();

    gridLayout->addWidget( label = new QLabel( tr( "Vertical systematic uncertainty:" ), this ) );
    label->setAlignment( Qt::AlignRight|Qt::AlignVCenter );
    yErrorSystWidget_ = new RefPointErrorWidget( this );
    gridLayout->addWidget( &yErrorSystWidget_->comboBox() );
    gridLayout->addWidget( &yErrorSystWidget_->plusEditor() );
    gridLayout->addWidget( &yErrorSystWidget_->minusEditor() );
    gridLayout->addWidget( &yErrorSystWidget_->relativeCheckBox() );
}

//_____________________________________________________________________
void RefPointErrorDialog::setPoint( const RefPoint& point )
{

    point_ = point;

    // formats
    globalLabel_->setText( RefPoint::Helper::toString( point.global(), XmlOptions::get().get<QString>( "GLOBAL_FORMAT" ) ) );
    localLabel_->setText( RefPoint::Helper::toString( point.local(), XmlOptions::get().get<QString>( "LOCAL_FORMAT" ) ) );

    xErrorWidget_->setError( point.errorX() );
    yErrorWidget_->setError( point.errorY() );

    xErrorSystWidget_->setError( point.errorSystX() );
    yErrorSystWidget_->setError( point.errorSystY() );

}

//_____________________________________________________________________
RefPoint RefPointErrorDialog::point() const
{
    RefPoint out( point_ );

    // errors
    xErrorWidget_->save( out.errorX() );
    yErrorWidget_->save( out.errorY() );

    xErrorSystWidget_->save( out.errorSystX() );
    yErrorSystWidget_->save( out.errorSystY() );

    return out;
}
