/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "RefPointErrorWidget.h"


//_____________________________________________________________________
RefPointErrorWidget::RefPointErrorWidget( QWidget* parent ):
    QObject( parent ),
    Counter( "RefPointErrorWidget" )
{
    Debug::Throw( "RefPointErrorWidget::RefPointErrorWidget" );

    // combobox
    combobox_ = new QComboBox( parent );

    // editor
    plusEditor_ = new LineEditor( parent );
    plusEditor_->setAlignment( Qt::AlignRight|Qt::AlignVCenter );
    plusEditor_->setValidator( new QDoubleValidator );

    // editor
    minusEditor_ = new LineEditor( parent );
    minusEditor_->setAlignment( Qt::AlignRight|Qt::AlignVCenter );
    minusEditor_->setValidator( new QDoubleValidator );

    // checkbox
    relativeCheckBox_ = new QCheckBox( tr( "Fractional" ), parent );

    // connections and setup
    connect( combobox_, SIGNAL(currentIndexChanged(int)), SLOT(_errorModeChanged(int)) );
    combobox_->addItems( QStringList() << tr( "None" ) << tr( "Symetric" ) << tr( "Asymetric" ) );
}

//_____________________________________________________________________
void RefPointErrorWidget::save( RefPoint::Error& error ) const
{

    error.mode_ = (RefPoint::ErrorMode) combobox_->currentIndex();
    error.relative_ = (RefPoint::ErrorMode) relativeCheckBox_->isChecked();
    error.plus_ = std::abs( plusEditor_->text().toDouble() );
    error.minus_ = (error.mode_ == RefPoint::ErrorSymetric) ? error.plus_ : std::abs( minusEditor_->text().toDouble() );

}

//_____________________________________________________________________
void RefPointErrorWidget::_errorModeChanged( int index )
{
    switch( (RefPoint::ErrorMode) index )
    {
        case RefPoint::NoError:
        plusEditor_->setEnabled( false );
        minusEditor_->setEnabled( false );
        relativeCheckBox_->setEnabled( false );
        break;

        case RefPoint::ErrorSymetric:
        plusEditor_->setEnabled( true );
        minusEditor_->setEnabled( false );
        relativeCheckBox_->setEnabled( true );
        break;

        case RefPoint::ErrorAsymetric:
        plusEditor_->setEnabled( true );
        minusEditor_->setEnabled( true );
        relativeCheckBox_->setEnabled( true );
        break;

        default: break;
    }

}
