#ifndef RefPointErrorWidget_h
#define RefPointErrorWidget_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Debug.h"
#include "RefPoint.h"
#include "LineEditor.h"

#include <QCheckBox>
#include <QComboBox>

class RefPointErrorWidget: public QObject, private Base::Counter<RefPointErrorWidget>
{

    Q_OBJECT

    public:

    //* constructor
    explicit RefPointErrorWidget( QWidget* );

    //*@name accessors
    //@{

    //* combobox
    QComboBox& comboBox()
    { return *combobox_; }

    //* plus editor
    LineEditor& plusEditor()
    { return *plusEditor_; }

    //* minus editor
    LineEditor& minusEditor()
    { return *minusEditor_; }

    //* relative checkbox
    QCheckBox& relativeCheckBox()
    { return *relativeCheckBox_; }

    //* save
    void save( RefPoint::Error& ) const;

    // error
    RefPoint::Error error() const
    {
        RefPoint::Error out;
        save( out );
        return out;
    }

    //@}

    //*@name modifiers
    //@{

    //* return error
    void setError( const RefPoint::Error& error )
    {
        combobox_->setCurrentIndex( error.mode_ );
        plusEditor_->setText( QString::number( error.plus_ ) );
        minusEditor_->setText( QString::number( error.minus_ ) );
        relativeCheckBox_->setChecked( error.relative_ );
    }

    //* enable state
    void setEnabled( bool value )
    {
        combobox_->setEnabled( value );
        plusEditor_->setEnabled( value );
        minusEditor_->setEnabled( value );
        relativeCheckBox_->setEnabled( value );
    }

    //* visible state
    void hide()
    { setVisible( false ); }

    //* visible state
    void setVisible( bool value )
    {
        combobox_->setVisible( value );
        plusEditor_->setVisible( value );
        minusEditor_->setVisible( value );
        relativeCheckBox_->setVisible( value );
    }

    //@}

    public Q_SLOTS:

    //* mode changed
    void _errorModeChanged( int );

    private:

    //* combobox
    QComboBox* combobox_ = nullptr;

    //* first editor
    LineEditor* plusEditor_ = nullptr;

    //* second editor
    LineEditor* minusEditor_ = nullptr;

    //* relative checkbox
    QCheckBox* relativeCheckBox_ = nullptr;

};

#endif
