#ifndef RefPointModel_h
#define RefPointModel_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "RefPoint.h"
#include "ListModel.h"

#include <array>

class RefPointModel: public ListModel<RefPoint>
{

    Q_OBJECT

    public:

    //* columns
    enum ColumnType
    {
        Index,
        Global,
        Local,
        ErrorsX,
        ErrorsY,
        ErrorsSystX,
        ErrorsSystY,
        nColumns
    };

    //* constructor
    explicit RefPointModel( QObject* parent = 0 ):
        ListModel<RefPoint>( parent ),
        refPointsValid_( true )
    {}

    //*@name methods reimplemented from base class
    //@{

    // return data for a given index
    QVariant data( const QModelIndex&, int ) const override;

    //* header data
    QVariant headerData( int, Qt::Orientation, int = Qt::DisplayRole ) const override;

    //* number of columns for a given index
    int columnCount( const QModelIndex& = QModelIndex() ) const override
    { return nColumns; }

    //@}

    //* local format
    void setGlobalFormat( const QString& );

    //* local format
    void setLocalFormat( const QString& );

    //* local format
    void setErrorFormat( const QString& );

    //* reference points valid
    void setRefPointsValid( bool value )
    { refPointsValid_ = value; }

    protected:

    //* convert error to string
    QString error( const RefPoint::Error&, const double& ) const;

    private:

    //* column titles
    const std::array<QString, nColumns> columnTitles_ =
    {{
        tr( "Index " ),
        tr( "Global" ),
        tr( "Local" ),
        tr( "Stat. (x)" ),
        tr( "Stat. (y)" ),
        tr( "Syst. (x)" ),
        tr( "Syst. (y)" )
    }};

    //* global number format
    QString globalFormat_;

    //* local number format
    QString localFormat_;

    //* error number format
    QString errorFormat_;

    //* true if reference points are valid
    bool refPointsValid_;

};

#endif
