#ifndef RefPointWidget_h
#define RefPointWidget_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"
#include "CustomToolBar.h"
#include "RefPoint.h"

#include <QLabel>
#include <QAction>
#include <QList>

class RefPointWidget: public QObject, private Base::Counter<RefPointWidget>
{

    Q_OBJECT

    public:

    //* shortcut
    using List = QList<RefPointWidget*>;

    //* constructor
    explicit RefPointWidget( QWidget* );

    //* set hovered
    bool setHovered( bool );

    //* hovered
    bool isHovered() const
    { return hovered_; }

    //* set selected
    bool setSelected( bool );

    //* true if selected
    bool isSelected() const
    { return selected_; }

    //*@name child widgets
    //@{
    //* name
    QLabel& nameLabel() const
    { return *nameLabel_; }

    //* global position
    QLabel& globalPointLabel() const
    { return *globalPointLabel_; }

    //* local position
    QLabel& localPointLabel() const
    { return *localPointLabel_; }

    //@}

    //* toolbar
    QToolBar& toolbar() const
    { return *toolbar_; }

    //*@name actions
    //@{

    //* edit
    QAction& editAction() const
    { return *editAction_; }

    //* clear
    QAction& clearAction() const
    { return *clearAction_; }

    //@}

    //* true if argument is child of this
    bool hasChild( const QObject* object ) const
    {
        return
            object == &nameLabel() ||
            object == &globalPointLabel() ||
            object == &localPointLabel();
    }

    //@}

    //*@name reference point
    //@{

    const RefPoint& point() const
    { return point_; }

    void setPoint( const RefPoint& );

    //* return true if valid
    bool isValid() const
    { return !( globalPointLabel().text().isEmpty() || localPointLabel().text().isEmpty() ); }

    //* clear
    void clear();

    //@}

    Q_SIGNALS:

    // emitted when modified
    void modified();

    private:

    //* true if initialized
    bool initialized_ = false;

    //* true if hovered
    bool hovered_ = false;

    //* true if selected
    bool selected_ = false;

    //* name label
    QLabel* nameLabel_ = nullptr;

    //* point label (global)
    QLabel* globalPointLabel_ = nullptr;

    //* Point label (local)
    QLabel* localPointLabel_ = nullptr;

    //* toolbar
    CustomToolBar* toolbar_ = nullptr;

    //*edit action
    QAction* editAction_ = nullptr;

    //* clear action
    QAction* clearAction_ = nullptr;

    //* associated reference point
    RefPoint point_;

};

#endif
