/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "UndoCommand.h"
#include "RefPointListWidget.h"

//____________________________________________________________________
void MarkerAddedCommand::undo()
{ if( _parent() ) _parent().data()->removePoint( _dataSetIndex(), point_ ); }

//____________________________________________________________________
void MarkerAddedCommand::redo()
{ if( _parent() ) _parent().data()->addPoint( _dataSetIndex(), point_ ); }

//____________________________________________________________________
void MarkerRemovedCommand::undo()
{
    if( !_parent() ) return;
    if( _refPointIndex() >= 0 ) _parent().data()->insertPoint( _dataSetIndex(), _refPointIndex(), point_ );
    else _parent().data()->addPoint( _dataSetIndex(), point_ );
}

//____________________________________________________________________
void MarkerRemovedCommand::redo()
{ if( _parent() ) _parent().data()->removePoint( _dataSetIndex(), point_ ); }

//____________________________________________________________________
void MarkerChangedCommand::undo()
{ if( _parent() ) _parent().data()->replacePoint( _dataSetIndex(), destination_, source_ ); }

//____________________________________________________________________
void MarkerChangedCommand::redo()
{ if( _parent() ) _parent().data()->replacePoint( _dataSetIndex(), source_, destination_ ); }

//____________________________________________________________________
bool MarkerChangedCommand::mergeWith( const QUndoCommand* command )
{
    const MarkerChangedCommand* other( static_cast<const MarkerChangedCommand*>( command ) );

    if( !_canMerge( other ) ) return false;
    if( _dataSetIndex() == other->_dataSetIndex() && destination_ == other->source_ )
    {
        setTime( other->time() );
        destination_ = other->destination_;
        return true;

    } else return false;
}

//____________________________________________________________________
void MarkersMovedCommand::_moveUp()
{
    if( !_parent() ) return;
    _parent().data()->refPointListWidget().setDataSetIndex( dataSetIndex_ );
    _parent().data()->refPointListWidget().movePointsUp( points_ );
}

//____________________________________________________________________
void MarkersMovedCommand::_moveDown()
{
    if( !_parent() ) return;
    _parent().data()->refPointListWidget().setDataSetIndex( dataSetIndex_ );
    _parent().data()->refPointListWidget().movePointsDown( points_ );
}

//____________________________________________________________________
void RefPointAddedCommand::undo()
{ if( _parent() ) _parent().data()->removeReferencePoint( _index() ); }

//____________________________________________________________________
void RefPointAddedCommand::redo()
{ if( _parent() ) _parent().data()->updateReferencePoint( _index(), point_ ); }

//____________________________________________________________________
void RefPointRemovedCommand::undo()
{ if( _parent() ) _parent().data()->updateReferencePoint( _index(), point_ ); }

//____________________________________________________________________
void RefPointRemovedCommand::redo()
{ if( _parent() ) _parent().data()->removeReferencePoint( _index() ); }

//____________________________________________________________________
void RefPointChangedCommand::undo()
{ if( _parent() ) _parent().data()->updateReferencePoint( _index(), source_ ); }

//____________________________________________________________________
void RefPointChangedCommand::redo()
{ if( _parent() ) _parent().data()->updateReferencePoint( _index(), destination_ ); }

//____________________________________________________________________
bool RefPointChangedCommand::mergeWith( const QUndoCommand* command )
{
    const RefPointChangedCommand* other( static_cast<const RefPointChangedCommand*>( command ) );

    if( !_canMerge( other ) ) return false;
    if( _index() == other->_index() && destination_ == other->source_ )
    {
        setTime( other->time() );
        destination_ = other->destination_;
        return true;

    } else return false;
}
