#ifndef ZoomWidget_h
#define ZoomWidget_h
/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"
#include "Debug.h"

#include <QAction>
#include <QWidget>

// forward declaration
class CustomComboBox;

class ZoomWidget: public QWidget, private Base::Counter<ZoomWidget>
{

    Q_OBJECT

    public:

    //* constructor
    explicit ZoomWidget( QWidget* = nullptr );

    //* zoom mode
    enum Mode
    {
        FitWidth,
        FitHeight,
        FitPage,
        Fixed
    };

    //* mode
    Mode mode() const
    { return mode_; }

    //* factor
    double factor() const
    { return factor_; }

    //* event filter
    bool eventFilter( QObject*, QEvent* );

    //*@name actions
    //@{

    QAction& zoomInAction()
    { return *zoomInAction_; }

    QAction& zoomOutAction()
    { return *zoomOutAction_; }

    //@}

    public Q_SLOTS:

    //* change "real" factor
    void realFactorChanged( double );

    Q_SIGNALS:

    //* modified
    void modified( ZoomWidget::Mode, double );

    protected Q_SLOTS:

    //* zoom in
    void _zoomIn( int = 1 );

    //* zoom out
    void _zoomOut( int = 1 );

    //* setup items
    void _setupItems( bool forced = false );

    //* current item changed
    void _currentIndexChanged( const QString& );

    protected:

    //* change factor
    void _setFactor( double );

    //* return index of nearest fixed factor matching current
    int _findNearestFactor( double ) const;

    private Q_SLOTS:

    //* configuration
    void _updateConfiguration();

    private:

    //*@name actions
    //@{
    QAction* zoomInAction_ = nullptr;
    QAction* zoomOutAction_ = nullptr;
    //@}

    //* combobox
    CustomComboBox* combobox_ = nullptr;

    //* zoom mode
    Mode mode_ = Fixed;

    //* zoom factor
    double factor_ = 1;

    //* zoom factor
    double realFactor_ = 1;

    //* true when configured at least once
    bool configured_ = false;

};

#endif
